sol.views – Pyramid views — SoL 3 developers documentation

### Navigation

- index
- modules |
- previous |
- Dev's documentation »
- SoL modules »

# `sol.views` – Pyramid views

class `sol.views.` `LoggerAdapter`(logger, extra)

  Add username and remote IP to the logged message

`sol.views.` `get_request_logger`(request, logger)

  Get a specialized logger for a Pyramid request

`sol.views.` `unauthorized_for_guest`(f)

  Prevent guest users to perform the operation.

### Navigation

- index
- modules |
- previous |
- Dev's documentation »
- SoL modules »